/*+*****************************************************************************
*                                                                              *
* File: util.h                                                                 *
*                                                                              *
**-****************************************************************************/

/*
 * @(#)util.h	1.8	02/02/98	Written by Lionel Cons
 */

#ifndef _util_h_
#define _util_h_

/******* Include Files ********************************************************/

/*
 * frequently used include files
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <errno.h>
#include <unistd.h>

/******* Constants ************************************************************/

/*
 * debugging flags
 */
#define DBG_ERROR	(1 <<  0)
#define DBG_MISC	(1 <<  1)
#define DBG_CONN	(1 <<  2)
#define DBG_UI		(1 <<  3)
#define DBG_X		(1 <<  4)
#define DBG_FSA		(1 <<  5)
#define DBG_IO		(1 <<  6)
#define DBG_IO_READ	(1 <<  7)
#define DBG_IO_WRITE	(1 <<  8)
#define DBG_AUTH	(1 <<  9)
#define DBG_LOG		(1 << 10)
#define DBG_MC		(1 << 11)
#define DBG_ALERT	(1 << 12)
#define DBG_DISPATCH	(1 << 13)
#define DBG_CONFIG	(1 << 14)
#define DBG_IDENT	(1 << 15)
#define DBG_ALL		0xFFFF

/******* Macros ***************************************************************/

/*
 * memory handling
 */
#define NEW(t)		((t *)safe_malloc(sizeof(t)))
#define OLD(p)		free((void *)p)
#define str_free(s)	free((void *)s)

/*
 * bit handling
 */
#define BITSET(v,b)	(v |=  (b))
#define BITCLR(v,b)	(v &= ~(b))
#define BITCHG(v,b)	(v ^=  (b))
#define BITTST(v,b)	(v &   (b))

/*
 * SunOS 4 support for strerror and memmove
 */
#if defined(sun) && !defined(SOLARIS) && !defined(__GLIBC__)
extern char *sys_errlist[];
extern int   sys_nerr;
#define strerror(n) \
    (((n) >= 0 && (n) < sys_nerr) ? sys_errlist[n] : "unknown error")
#define memmove(dst,src,len) bcopy(src,dst,len)
#endif

/*
 * misc
 */
#define ERROR		strerror(errno)
#ifdef DEBUG
#define DEBUGGING(x)	(debug & x)
#endif

/******* Types ****************************************************************/

/******* Variables ************************************************************/

#ifdef DEBUG
extern int debug;
extern char *timetag;
#endif

/******* Functions ************************************************************/

#ifdef DEBUG
void hexdump(char *, int);
void dprintf(char *, char *, ...);
#endif
void die(char *, ...);
void *safe_malloc(int);
char *str_ncopy(char *, int);
char *str_copy(char *);
void util_setup(char *);

#endif /* _util_h_ */
/* DON'T ADD ANYTHING AFTER THIS LINE */
